Getting Started
===============

.. toctree::
    :maxdepth: 1

    quick
    requirements
    downloading
    installing
    tools

.. todo:: Simplify the installation documents by stringing them together, so the other setup documents are more visible
.. todo:: Add setup section
.. todo:: Add crew setup
.. todo:: Add vessel setup
.. todo:: Add generic preferences setup